package com.miaxis.app.controller.news;

import java.util.List;

import com.miaxis.common.constant.Constants;
import io.swagger.annotations.*;
import com.miaxis.common.core.domain.Response;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.bind.annotation.ModelAttribute;
import com.miaxis.common.annotation.Log;
import com.miaxis.common.core.controller.BaseController;
import com.miaxis.common.enums.BusinessTypeEnum;
import com.miaxis.system.domain.NewsInfo;
import com.miaxis.system.service.INewsInfoService;
import com.miaxis.common.utils.poi.ExcelUtil;
import com.miaxis.common.core.page.ResponsePageInfo;

/**
 * 【新闻(首页资讯、通知、公告相关)】Controller
 *
 * @author miaxis
 * @date 2020-12-22
 */
@RestController
@RequestMapping(Constants.OPEN_PREFIX+"/system/info")
@Api(tags={"【新闻(首页资讯、通知、公告相关)】Controller"})
public class NewsInfoController extends BaseController{
    @Autowired
    private INewsInfoService newsInfoService;

    /**
     * 查询新闻(首页资讯、通知、公告相关)列表
     */
    @GetMapping("/list")
    @ApiOperation("查询新闻(首页资讯、通知、公告相关)列表")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum",value = "当前页码" ,dataType = "int", paramType = "query", required = false),
            @ApiImplicitParam(name = "pageSize",value = "每页数据量" , dataType = "int", paramType = "query", required = false),
    })
    public ResponsePageInfo<NewsInfo> list(@ModelAttribute NewsInfo newsInfo){
        startPage();
        List<NewsInfo> list = newsInfoService.selectNewsInfoList(newsInfo);
//        List<NewsInfo> list = newsInfoService.list();
        return toResponsePageInfo(list);
    }

    /**
     * 导出新闻(首页资讯、通知、公告相关)列表
     */
    @Log(title = "新闻(首页资讯、通知、公告相关)", businessType = BusinessTypeEnum.EXPORT)
    @GetMapping("/export")
    @ApiOperation("导出新闻(首页资讯、通知、公告相关)列表Excel")
    public Response<String> export(@ModelAttribute NewsInfo newsInfo){
        List<NewsInfo> list = newsInfoService.selectNewsInfoList(newsInfo);
        ExcelUtil<NewsInfo> util = new ExcelUtil<NewsInfo>(NewsInfo.class);
        return util.exportExcel(list, "info");
    }

    /**
     * 获取新闻(首页资讯、通知、公告相关)详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:info:query')")
    @GetMapping(value = "/{id}")
    @ApiOperation("获取新闻(首页资讯、通知、公告相关)详细信息")
    public Response<NewsInfo> getInfo(
            @ApiParam(name = "id", value = "新闻(首页资讯、通知、公告相关)参数", required = true)
            @PathVariable("id") Long id
    ){
        return Response.success(newsInfoService.selectNewsInfoById(id));
    }

    /**
     * 新增新闻(首页资讯、通知、公告相关)
     */
    @Log(title = "新闻(首页资讯、通知、公告相关)", businessType = BusinessTypeEnum.INSERT)
    @PostMapping
    @ApiOperation("新增新闻(首页资讯、通知、公告相关)")
    public Response<Integer> add(@RequestBody NewsInfo newsInfo){
        return toResponse(newsInfoService.insertNewsInfo(newsInfo));
    }

    /**
     * 修改新闻(首页资讯、通知、公告相关)
     */
    @Log(title = "新闻(首页资讯、通知、公告相关)", businessType = BusinessTypeEnum.UPDATE)
    @PutMapping
    @ApiOperation("修改新闻(首页资讯、通知、公告相关)")
    public Response<Integer> edit(@RequestBody NewsInfo newsInfo){
        return toResponse(newsInfoService.updateNewsInfo(newsInfo));
    }

    /**
     * 删除新闻(首页资讯、通知、公告相关)
     */
    @Log(title = "新闻(首页资讯、通知、公告相关)", businessType = BusinessTypeEnum.DELETE)
	@DeleteMapping("/{ids}")
    @ApiOperation("删除新闻(首页资讯、通知、公告相关)")
    public  Response<Integer> remove(
            @ApiParam(name = "ids", value = "新闻(首页资讯、通知、公告相关)ids参数", required = true)
            @PathVariable Long[] ids
    ){
        return toResponse(newsInfoService.deleteNewsInfoByIds(ids));
    }
}
