package com.miaxis.app.controller.school;

import java.util.List;
import io.swagger.annotations.*;
import com.miaxis.common.core.domain.Response;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.bind.annotation.ModelAttribute;
import com.miaxis.common.annotation.Log;
import com.miaxis.common.core.controller.BaseController;
import com.miaxis.common.enums.BusinessTypeEnum;
import com.miaxis.system.domain.SchoolRegion;
import com.miaxis.system.service.ISchoolRegionService;
import com.miaxis.common.utils.poi.ExcelUtil;
import com.miaxis.common.core.page.ResponsePageInfo;

/**
 * 【驾校训练场】Controller
 *
 * @author miaxis
 * @date 2020-12-23
 */
@RestController
@RequestMapping("/system/region")
@Api(tags={"【驾校训练场】Controller"})
public class SchoolRegionController extends BaseController{
    @Autowired
    private ISchoolRegionService schoolRegionService;

    /**
     * 查询驾校训练场列表
     */
    @PreAuthorize("@ss.hasPermi('system:region:list')")
    @GetMapping("/list")
    @ApiOperation("查询驾校训练场列表")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum",value = "当前页码" ,dataType = "int", paramType = "query", required = false),
            @ApiImplicitParam(name = "pageSize",value = "每页数据量" , dataType = "int", paramType = "query", required = false),
    })
    public ResponsePageInfo<SchoolRegion> list(@ModelAttribute SchoolRegion schoolRegion){
        startPage();
        List<SchoolRegion> list = schoolRegionService.selectSchoolRegionList(schoolRegion);
        return toResponsePageInfo(list);
    }

    /**
     * 导出驾校训练场列表
     */
    @PreAuthorize("@ss.hasPermi('system:region:export')")
    @Log(title = "驾校训练场", businessType = BusinessTypeEnum.EXPORT)
    @GetMapping("/export")
    @ApiOperation("导出驾校训练场列表Excel")
    public Response<String> export(@ModelAttribute SchoolRegion schoolRegion){
        List<SchoolRegion> list = schoolRegionService.selectSchoolRegionList(schoolRegion);
        ExcelUtil<SchoolRegion> util = new ExcelUtil<SchoolRegion>(SchoolRegion.class);
        return util.exportExcel(list, "region");
    }

    /**
     * 获取驾校训练场详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:region:query')")
    @GetMapping(value = "/{id}")
    @ApiOperation("获取驾校训练场详细信息")
    public Response<SchoolRegion> getInfo(
            @ApiParam(name = "id", value = "驾校训练场参数", required = true)
            @PathVariable("id") Long id
    ){
        return Response.success(schoolRegionService.selectSchoolRegionById(id));
    }

    /**
     * 新增驾校训练场
     */
    @PreAuthorize("@ss.hasPermi('system:region:add')")
    @Log(title = "驾校训练场", businessType = BusinessTypeEnum.INSERT)
    @PostMapping
    @ApiOperation("新增驾校训练场")
    public Response<Integer> add(@RequestBody SchoolRegion schoolRegion){
        return toResponse(schoolRegionService.insertSchoolRegion(schoolRegion));
    }

    /**
     * 修改驾校训练场
     */
    @PreAuthorize("@ss.hasPermi('system:region:edit')")
    @Log(title = "驾校训练场", businessType = BusinessTypeEnum.UPDATE)
    @PutMapping
    @ApiOperation("修改驾校训练场")
    public Response<Integer> edit(@RequestBody SchoolRegion schoolRegion){
        return toResponse(schoolRegionService.updateSchoolRegion(schoolRegion));
    }

    /**
     * 删除驾校训练场
     */
    @PreAuthorize("@ss.hasPermi('system:region:remove')")
    @Log(title = "驾校训练场", businessType = BusinessTypeEnum.DELETE)
	@DeleteMapping("/{ids}")
    @ApiOperation("删除驾校训练场")
    public  Response<Integer> remove(
            @ApiParam(name = "ids", value = "驾校训练场ids参数", required = true)
            @PathVariable Long[] ids
    ){
        return toResponse(schoolRegionService.deleteSchoolRegionByIds(ids));
    }
}
