package com.miaxis.app.controller.user;

import com.miaxis.app.user.domain.UserInfo;
import com.miaxis.app.user.service.IUserInfoService;
import com.miaxis.common.annotation.Log;
import com.miaxis.common.constant.Constants;
import com.miaxis.common.core.controller.BaseController;
import com.miaxis.common.core.domain.Response;
import com.miaxis.common.core.domain.entity.SysUser;
import com.miaxis.common.core.page.ResponsePageInfo;
import com.miaxis.common.enums.BusinessTypeEnum;
import com.miaxis.common.utils.SecurityUtils;
import com.miaxis.common.utils.poi.ExcelUtil;
import io.swagger.annotations.*;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * 【用户信息】Controller
 *
 * @author miaxis
 * @date 2020-12-23
 */
@RestController
@RequestMapping(Constants.OPEN_PREFIX+"/user/info")
@Api(tags={"【普通用户信息】Controller"})
public class UserInfoController extends BaseController{
    @Autowired
    private IUserInfoService userInfoService;

    /**
     * 查询用户信息列表
     */
    @GetMapping("/list")
    @ApiOperation("查询用户信息列表")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum",value = "当前页码" ,dataType = "int", paramType = "query", required = false),
            @ApiImplicitParam(name = "pageSize",value = "每页数据量" , dataType = "int", paramType = "query", required = false),
    })
    public ResponsePageInfo<UserInfo> list(@ModelAttribute UserInfo userInfo){
        startPage();
        List<UserInfo> list = userInfoService.list();
        return toResponsePageInfo(list);
    }

    /**
     * 导出用户信息列表
     */
    @Log(title = "用户信息", businessType = BusinessTypeEnum.EXPORT)
    @GetMapping("/export")
    @ApiOperation("导出用户信息列表Excel")
    public Response<String> export(@ModelAttribute UserInfo userInfo){
        List<UserInfo> list = userInfoService.selectUserInfoList(userInfo);
        ExcelUtil<UserInfo> util = new ExcelUtil<UserInfo>(UserInfo.class);
        return util.exportExcel(list, "info");
    }

    /**
     * 获取用户信息详细信息
     */
    @GetMapping(value = "/{id}")
    @ApiOperation("获取用户信息详细信息")
    public Response<UserInfo> getInfo(
            @ApiParam(name = "id", value = "用户信息参数", required = true)
            @PathVariable("id") Long id
    ){
        return Response.success(userInfoService.selectUserInfoById(id));
    }

    /**
     * 新增用户信息
     */
    @Log(title = "用户信息", businessType = BusinessTypeEnum.INSERT)
    @PostMapping
    @ApiOperation("新增用户信息")
    public Response<Integer> add(@RequestBody UserInfo userInfo){
        return toResponse(userInfoService.insertUserInfo(userInfo));
    }

    /**
     * 修改用户信息
     */
    @Log(title = "用户信息", businessType = BusinessTypeEnum.UPDATE)
    @PutMapping
    @ApiOperation("修改用户信息")
    public Response<Integer> edit(@RequestBody UserInfo userInfo){
        return toResponse(userInfoService.updateUserInfo(userInfo));
    }

    /**
     * 删除用户信息
     */
    @Log(title = "用户信息", businessType = BusinessTypeEnum.DELETE)
	@DeleteMapping("/{ids}")
    @ApiOperation("删除用户信息")
    public  Response<Integer> remove(
            @ApiParam(name = "ids", value = "用户信息ids参数", required = true)
            @PathVariable Long[] ids
    ){
        return toResponse(userInfoService.deleteUserInfoByIds(ids));
    }

    /**
     * 修改用户手机号
     */
    @Log(title = "用户信息", businessType = BusinessTypeEnum.UPDATE)
    @PostMapping("/modifyPhoneNumber")
    @ApiOperation("修改用户手机号")
    public Response modifyPhoneNumber(String phone,String verificationCode){
        //获取当前用户
        SysUser user = SecurityUtils.getLoginUser().getUser();
        //修改手机号
        return userInfoService.modifyPhoneNumber(phone,verificationCode,user);
    }


}
