package com.miaxis.system.controller.common;

import com.miaxis.common.constant.Constants;
import com.miaxis.common.core.domain.Response;
import com.miaxis.common.core.domain.ResponseEnum;
import com.miaxis.common.core.domain.entity.SysUser;
import com.miaxis.common.sms.Client;
import com.miaxis.common.utils.SecurityUtils;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.net.URLEncoder;
import java.util.HashMap;
import java.util.Map;
import java.util.Random;
import java.util.concurrent.TimeUnit;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

/**
 * @Author wwl
 * @Date 2020/12/23
 * @Version 1.0
 */
@RestController
@RequestMapping("/user/info")
@Api(tags={"【短信服务】Controller"})
public class smsController {

    private final String MOBILE_REGEX = "^((13[0-9])|(14[0-9])|(15[0-9])|(17[0-9])|(18[0-9])|(19[0-9]))\\d{8}$";//手机号码验证
    private final Integer SMS_MAX_COUNT = 500 ;//每天系统发送最大次数(预留)
    private final Integer MAX_COUNT = 5 ;//每个手机号验证发送最大次数
    private final long SEND_INTERVAL = 2 ;//发送间隔时间

    @Value("${sms_user_name}")
    private String smsUserName;//用户名

    @Value("${sms_password}")
    private String smsPassword;//密码

    @Autowired
    private RedisTemplate redisTemplate;//redis模板引擎


    /**
     * 获取短信验证码
     * @return
     */
    @ApiOperation("获取短信验证码")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "type",value = "login:用户登录验证码、modify:修改手机验证码" ,dataType = "String",required = true),
            @ApiImplicitParam(name = "phone", value = "手机号码", required = true, dataType = "String")
    })
    @PostMapping(value = "/sendVerificationCode")
    public Response sendVerificationCode(String type,String phone){
        //获取当前用户
        SysUser user = SecurityUtils.getLoginUser().getUser();
        //字符编码
        String charset = "UTF-8";

        //手机号格式验证
        if(phone.length() != 11){
            return Response.error(500,"手机格式错误");
        } else {
            Pattern pattern = Pattern.compile(MOBILE_REGEX);
            Matcher matcher = pattern.matcher(phone);
            if(!matcher.matches()) {
                return Response.error(500,"手机号格式错误");
            }
        }
        try{

            /**
             * login:登录验证  modify；修改验证
             * keyPrefix : 缓存key前缀
             * verificationCount : 验证次数
             */
            Map<String, String> map = new HashMap<>();
            if (type.equals("login")){
                map.put("keyPrefix",Constants.SMS_LOGIN_CODE);
                map.put("verificationCount",Constants.SMS_LOGIN_CODE_COUNT);
            }
            if (type.equals("modify")){
                if (user.getPhonenumber().equals(phone)){
                    return Response.error(500,"该手机号与当前绑定的手机号相同");
                }
                map.put("keyPrefix",Constants.SMS_MODIFY_CODE);
                map.put("verificationCount",Constants.SMS_MODIFY_CODE_COUNT);
            }

            //验证手机号
            Response resultJson = validateMobile(phone,map);
            if("500".equals(resultJson.getCode().toString())) {
                return resultJson;
            }

            // 生成验证码
             String code="";
            for (int i=0;i<6;i++){
                code += new Random().nextInt(10);
            }
            String content = "本次验证码："+code+",验证码两分钟内有效";

            // 调用发送接口
            Client client = new Client(smsUserName, smsPassword);
            String content1 = URLEncoder.encode(content, charset);
            String ecodeContent = URLEncoder.encode(content1, charset);
            String result = client.mtData(ecodeContent, phone, "", "", "", charset);
            String strCode = result.split("\n")[0];
            long codenum = 0;
            codenum = Long.valueOf(strCode);
            String Info = null;
            if (codenum > 0) {//成功提交
                Info = "发送成功";
                // 写入缓存中
                writeCache(phone, code,map);
                return Response.success(Info);

            } else if (codenum == 0) {
                Info = "发送失败";
            } else if (codenum == -1) { // 用户名密码不正确
                Info = "用户名密码不正确";
            } else if (codenum == -2) { // 必填选项为空
                Info = "必填选项为空";
            } else if (codenum == -3) { // 短信内容0个字节
                Info = "短信内容0个字节";
            } else if (codenum == -4) { // 0个有效号码
                Info = "0个有效号码";
            } else if (codenum == -5) { // 余额不够
                Info = "余额不够";
            } else if (codenum == -10) { // 用户被禁用
                Info = "用户被禁用";
            } else if (codenum == -11) { // 短信内容过长
                Info = "短信内容过长";
            } else if(codenum == -12){	 //用户无扩展权限
                Info = "无扩展权限";
            } else if(codenum == -13){  //IP地址校验错
                Info = "IP校验错误";
            } else if(codenum == -14){  //内容解析异常
                Info = "内容解析异常";
            } else {
                Info = "未知错误";
            }

            return Response.error(500,Info);
        } catch (Exception e) {
            e.printStackTrace();
            return Response.error(ResponseEnum.ERROR);
        }
    }

    /**
     * 手机号验证
     * @param mobile
     * @return
     */
    private Response validateMobile(final String mobile,Map map){

        if(redisTemplate.hasKey(map.get("verificationCount") + mobile)){
            // 验证发送时间
            if (redisTemplate.hasKey(map.get("keyPrefix") + mobile)){
                return Response.error(500,"验证码还未过期，不能重新发送!");
            }

            // 验证发送次数
            Integer count = Integer.valueOf(redisTemplate.opsForValue().get(map.get("verificationCount") + mobile).toString());
            if(count >= MAX_COUNT) {
                return Response.error(500,"当前手机号发送验证码次数过多!");
            }
        }
        return Response.success();
    }


    /**
     * 写入缓存
     * @param mobile
     * @param code
     */
    private void writeCache(String mobile, String code,Map map){

        //该手机号首次获取验证码
        if(!redisTemplate.hasKey(map.get("keyPrefix") + mobile) && !redisTemplate.hasKey(map.get("verificationCount") + mobile)){
            synchronized(this){
                //设置该手机号验证码 两分钟过期
                redisTemplate.opsForValue().set(map.get("keyPrefix") + mobile , code, SEND_INTERVAL, TimeUnit.MINUTES);
                //设置该手机号验证次数 一天过期
                redisTemplate.opsForValue().set(map.get("verificationCount") + mobile , "1",1,TimeUnit.DAYS);
            }
        }

        //多次获取验证码
        if (redisTemplate.hasKey(map.get("verificationCount") + mobile) && !redisTemplate.hasKey(map.get("keyPrefix") + mobile)){
            //判断该手机验证次数
            Integer count = Integer.valueOf(redisTemplate.opsForValue().get(map.get("verificationCount") + mobile).toString());
            if (count < MAX_COUNT){
                synchronized(this){
                    //该手机号验证次数+1 一天过期
                    redisTemplate.opsForValue().set(map.get("verificationCount") + mobile,String.valueOf(count+1),1,TimeUnit.DAYS);
                    //设置该手机号验证码 两分钟过期
                    redisTemplate.opsForValue().set(map.get("keyPrefix") + mobile , code, SEND_INTERVAL, TimeUnit.MINUTES);
                }
            }
        }
    }



}
