package com.miaxis.app.user.service.impl;

import java.util.List;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.miaxis.common.constant.Constants;
import com.miaxis.common.core.domain.Response;
import com.miaxis.common.core.domain.entity.SysUser;
import com.miaxis.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.stereotype.Service;
import com.miaxis.app.user.mapper.UserInfoMapper;
import com.miaxis.app.user.domain.UserInfo;
import com.miaxis.app.user.service.IUserInfoService;
import org.springframework.transaction.annotation.Transactional;

/**
 * 用户信息Service业务层处理
 *
 * @author miaxis
 * @date 2020-12-23
 */
@Service
public class UserInfoServiceImpl extends ServiceImpl<UserInfoMapper, UserInfo> implements IUserInfoService {
    @Autowired
    private UserInfoMapper userInfoMapper;

    @Autowired
    private RedisTemplate redisTemplate;

    /**
     * 查询用户信息
     *
     * @param id 用户信息ID
     * @return 用户信息
     */
    @Override
    public UserInfo selectUserInfoById(Long id){
        return userInfoMapper.selectUserInfoById(id);
    }

    /**
     * 查询用户信息列表
     *
     * @param userInfo 用户信息
     * @return 用户信息
     */
    @Override
    public List<UserInfo> selectUserInfoList(UserInfo userInfo){
        return userInfoMapper.selectUserInfoList(userInfo);
    }

    /**
     * 新增用户信息
     *
     * @param userInfo 用户信息
     * @return 结果
     */
    @Override
    public int insertUserInfo(UserInfo userInfo){
        userInfo.setCreateTime(DateUtils.getNowDate());
        return userInfoMapper.insertUserInfo(userInfo);
    }

    /**
     * 修改用户信息
     *
     * @param userInfo 用户信息
     * @return 结果
     */
    @Override
    public int updateUserInfo(UserInfo userInfo){
        userInfo.setUpdateTime(DateUtils.getNowDate());
        return userInfoMapper.updateUserInfo(userInfo);
    }

    /**
     * 批量删除用户信息
     *
     * @param ids 需要删除的用户信息ID
     * @return 结果
     */
    @Override
    public int deleteUserInfoByIds(Long[] ids){
        return userInfoMapper.deleteUserInfoByIds(ids);
    }

    /**
     * 删除用户信息信息
     *
     * @param id 用户信息ID
     * @return 结果
     */
    @Override
    public int deleteUserInfoById(Long id){
        return userInfoMapper.deleteUserInfoById(id);
    }

    /**
     * 修改手机号
     * @param phone
     * @param verificationCode
     * @return
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public Response modifyPhoneNumber(String phone,String verificationCode,SysUser user) {
        //查看验证码是否过期
        if (redisTemplate.hasKey(Constants.SMS_MODIFY_CODE_COUNT + phone) &&
                !redisTemplate.hasKey(Constants.SMS_MODIFY_CODE + phone)){
            return Response.error(500,"验证码已过期,请重新验证!");
        }
        //比对缓存中的验证码
        String smsCodeValue = redisTemplate.opsForValue().get(Constants.SMS_MODIFY_CODE + phone).toString();
        if (!verificationCode.equals(smsCodeValue)){
            return Response.error(500,"验证码错误,请重新输入");
        }

        UserInfo userInfo = new UserInfo();
        userInfo.setId(user.getUserId());
        userInfo.setMobile(phone);
        //更新绑定手机号
        userInfoMapper.updateById(userInfo);

        return Response.success();
    }
}
